# This file is encoded in Char::KPS9566.
die "This file is not encoded in Char::KPS9566.\n" if q{あ} ne "\x82\xa0";

use Char::KPS9566 qw(getc);
print "1..1\n";

my $__FILE__ = __FILE__;

my @getc = ();
while (my $c = getc(DATA)) {
    last if $c =~ /\A[\r\n]\z/;
    push @getc, $c;
}
my $result = join('', map {"($_)"} @getc);

if ($result eq '(1)(2)(あ)(い)') {
    print "ok - 1 $^X $__FILE__ 12あい --> $result.\n";
}
else {
    print "not ok - 1 $^X $__FILE__ 12あい --> $result.\n";
}

__END__
12あい
