# This file is encoded in Char::KPS9566.
die "This file is not encoded in Char::KPS9566.\n" if q{‚ } ne "\x82\xa0";

use strict;
use Char::KPS9566;
print "1..56\n";

my $__FILE__ = __FILE__;

if ('A' =~ m'A') {
    print qq{ok - 1 'A' =~ m'A' $^X $__FILE__\n};
}
else {
    print qq{not ok - 1 'A' =~ m'A' $^X $__FILE__\n};
}

if ('A' =~ m'A'b) {
    print qq{ok - 2 'A' =~ m'A'b $^X $__FILE__\n};
}
else {
    print qq{not ok - 2 'A' =~ m'A'b $^X $__FILE__\n};
}

if ('A' =~ m'a'i) {
    print qq{ok - 3 'A' =~ m'a'i $^X $__FILE__\n};
}
else {
    print qq{not ok - 3 'A' =~ m'a'i $^X $__FILE__\n};
}

if ('A' =~ m'a'ib) {
    print qq{ok - 4 'A' =~ m'a'ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 4 'A' =~ m'a'ib $^X $__FILE__\n};
}

if ('a' =~ m'A') {
    print qq{not ok - 5 'a' =~ m'A' $^X $__FILE__\n};
}
else {
    print qq{ok - 5 'a' =~ m'A' $^X $__FILE__\n};
}

if ('a' =~ m'A'b) {
    print qq{not ok - 6 'a' =~ m'A'b $^X $__FILE__\n};
}
else {
    print qq{ok - 6 'a' =~ m'A'b $^X $__FILE__\n};
}

if ('a' =~ m'a'i) {
    print qq{ok - 7 'a' =~ m'a'i $^X $__FILE__\n};
}
else {
    print qq{not ok - 7 'a' =~ m'a'i $^X $__FILE__\n};
}

if ('a' =~ m'a'ib) {
    print qq{ok - 8 'a' =~ m'a'ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 8 'a' =~ m'a'ib $^X $__FILE__\n};
}

if ('A' =~ m'ƒA') {
    print qq{not ok - 9 'A' =~ m'ƒA' $^X $__FILE__\n};
}
else {
    print qq{ok - 9 'A' =~ m'ƒA' $^X $__FILE__\n};
}

if ('A' =~ m'ƒA'b) {
    print qq{not ok - 10 'A' =~ m'ƒA'b $^X $__FILE__\n};
}
else {
    print qq{ok - 10 'A' =~ m'ƒA'b $^X $__FILE__\n};
}

if ('A' =~ m'ƒA'i) {
    print qq{not ok - 11 'A' =~ m'ƒA'i $^X $__FILE__\n};
}
else {
    print qq{ok - 11 'A' =~ m'ƒA'i $^X $__FILE__\n};
}

if ('A' =~ m'ƒA'ib) {
    print qq{not ok - 12 'A' =~ m'ƒA'ib $^X $__FILE__\n};
}
else {
    print qq{ok - 12 'A' =~ m'ƒA'ib $^X $__FILE__\n};
}

if ('A' =~ m'ƒa') {
    print qq{not ok - 13 'A' =~ m'ƒa' $^X $__FILE__\n};
}
else {
    print qq{ok - 13 'A' =~ m'ƒa' $^X $__FILE__\n};
}

if ('A' =~ m'ƒa'b) {
    print qq{not ok - 14 'A' =~ m'ƒa'b $^X $__FILE__\n};
}
else {
    print qq{ok - 14 'A' =~ m'ƒa'b $^X $__FILE__\n};
}

if ('A' =~ m'ƒa'i) {
    print qq{not ok - 15 'A' =~ m'ƒa'i $^X $__FILE__\n};
}
else {
    print qq{ok - 15 'A' =~ m'ƒa'i $^X $__FILE__\n};
}

if ('A' =~ m'ƒa'ib) {
    print qq{not ok - 16 'A' =~ m'ƒa'ib $^X $__FILE__\n};
}
else {
    print qq{ok - 16 'A' =~ m'ƒa'ib $^X $__FILE__\n};
}

if ('a' =~ m'ƒA') {
    print qq{not ok - 17 'a' =~ m'ƒA' $^X $__FILE__\n};
}
else {
    print qq{ok - 17 'a' =~ m'ƒA' $^X $__FILE__\n};
}

if ('a' =~ m'ƒA'b) {
    print qq{not ok - 18 'a' =~ m'ƒA'b $^X $__FILE__\n};
}
else {
    print qq{ok - 18 'a' =~ m'ƒA'b $^X $__FILE__\n};
}

if ('a' =~ m'ƒA'i) {
    print qq{not ok - 19 'a' =~ m'ƒA'i $^X $__FILE__\n};
}
else {
    print qq{ok - 19 'a' =~ m'ƒA'i $^X $__FILE__\n};
}

if ('a' =~ m'ƒA'ib) {
    print qq{not ok - 20 'a' =~ m'ƒA'ib $^X $__FILE__\n};
}
else {
    print qq{ok - 20 'a' =~ m'ƒA'ib $^X $__FILE__\n};
}

if ('a' =~ m'ƒa') {
    print qq{not ok - 21 'a' =~ m'ƒa' $^X $__FILE__\n};
}
else {
    print qq{ok - 21 'a' =~ m'ƒa' $^X $__FILE__\n};
}

if ('a' =~ m'ƒa'b) {
    print qq{not ok - 22 'a' =~ m'ƒa'b $^X $__FILE__\n};
}
else {
    print qq{ok - 22 'a' =~ m'ƒa'b $^X $__FILE__\n};
}

if ('a' =~ m'ƒa'i) {
    print qq{not ok - 23 'a' =~ m'ƒa'i $^X $__FILE__\n};
}
else {
    print qq{ok - 23 'a' =~ m'ƒa'i $^X $__FILE__\n};
}

if ('a' =~ m'ƒa'ib) {
    print qq{not ok - 24 'a' =~ m'ƒa'ib $^X $__FILE__\n};
}
else {
    print qq{ok - 24 'a' =~ m'ƒa'ib $^X $__FILE__\n};
}

if ('ƒA' =~ m'A') {
    print qq{not ok - 25 'ƒA' =~ m'A' $^X $__FILE__\n};
}
else {
    print qq{ok - 25 'ƒA' =~ m'A' $^X $__FILE__\n};
}

if ('ƒA' =~ m'A'b) {
    print qq{ok - 26 'ƒA' =~ m'A'b $^X $__FILE__\n};
}
else {
    print qq{not ok - 26 'ƒA' =~ m'A'b $^X $__FILE__\n};
}

if ('ƒA' =~ m'A'i) {
    print qq{not ok - 27 'ƒA' =~ m'A'i $^X $__FILE__\n};
}
else {
    print qq{ok - 27 'ƒA' =~ m'A'i $^X $__FILE__\n};
}

if ('ƒA' =~ m'A'ib) {
    print qq{ok - 28 'ƒA' =~ m'A'ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 28 'ƒA' =~ m'A'ib $^X $__FILE__\n};
}

if ('ƒA' =~ m'a') {
    print qq{not ok - 29 'ƒA' =~ m'a' $^X $__FILE__\n};
}
else {
    print qq{ok - 29 'ƒA' =~ m'a' $^X $__FILE__\n};
}

if ('ƒA' =~ m'a'b) {
    print qq{not ok - 30 'ƒA' =~ m'a'b $^X $__FILE__\n};
}
else {
    print qq{ok - 30 'ƒA' =~ m'a'b $^X $__FILE__\n};
}

if ('ƒA' =~ m'a'i) {
    print qq{not ok - 31 'ƒA' =~ m'a'i $^X $__FILE__\n};
}
else {
    print qq{ok - 31 'ƒA' =~ m'a'i $^X $__FILE__\n};
}

if ('ƒA' =~ m'a'ib) {
    print qq{ok - 32 'ƒA' =~ m'a'ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 32 'ƒA' =~ m'a'ib $^X $__FILE__\n};
}

if ('ƒa' =~ m'A') {
    print qq{not ok - 33 'ƒa' =~ m'A' $^X $__FILE__\n};
}
else {
    print qq{ok - 33 'ƒa' =~ m'A' $^X $__FILE__\n};
}

if ('ƒa' =~ m'A'b) {
    print qq{not ok - 34 'ƒa' =~ m'A'b $^X $__FILE__\n};
}
else {
    print qq{ok - 34 'ƒa' =~ m'A'b $^X $__FILE__\n};
}

if ('ƒa' =~ m'A'i) {
    print qq{not ok - 35 'ƒa' =~ m'A'i $^X $__FILE__\n};
}
else {
    print qq{ok - 35 'ƒa' =~ m'A'i $^X $__FILE__\n};
}

if ('ƒa' =~ m'A'ib) {
    print qq{ok - 36 'ƒa' =~ m'A'ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 36 'ƒa' =~ m'A'ib $^X $__FILE__\n};
}

if ('ƒa' =~ m'a') {
    print qq{not ok - 37 'ƒa' =~ m'a' $^X $__FILE__\n};
}
else {
    print qq{ok - 37 'ƒa' =~ m'a' $^X $__FILE__\n};
}

if ('ƒa' =~ m'a'b) {
    print qq{ok - 38 'ƒa' =~ m'a'b $^X $__FILE__\n};
}
else {
    print qq{not ok - 38 'ƒa' =~ m'a'b $^X $__FILE__\n};
}

if ('ƒa' =~ m'a'i) {
    print qq{not ok - 39 'ƒa' =~ m'a'i $^X $__FILE__\n};
}
else {
    print qq{ok - 39 'ƒa' =~ m'a'i $^X $__FILE__\n};
}

if ('ƒa' =~ m'a'ib) {
    print qq{ok - 40 'ƒa' =~ m'a'ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 40 'ƒa' =~ m'a'ib $^X $__FILE__\n};
}

if ('ƒƒA' =~ m'ƒA') {
    print qq{not ok - 41 'ƒƒA' =~ m'ƒA' $^X $__FILE__\n};
}
else {
    print qq{ok - 41 'ƒƒA' =~ m'ƒA' $^X $__FILE__\n};
}

if ('ƒƒA' =~ m'ƒA'b) {
    print qq{ok - 42 'ƒƒA' =~ m'ƒA'b $^X $__FILE__\n};
}
else {
    print qq{not ok - 42 'ƒƒA' =~ m'ƒA'b $^X $__FILE__\n};
}

if ('ƒƒA' =~ m'ƒA'i) {
    print qq{not ok - 43 'ƒƒA' =~ m'ƒA'i $^X $__FILE__\n};
}
else {
    print qq{ok - 43 'ƒƒA' =~ m'ƒA'i $^X $__FILE__\n};
}

if ('ƒƒA' =~ m'ƒA'ib) {
    print qq{ok - 44 'ƒƒA' =~ m'ƒA'ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 44 'ƒƒA' =~ m'ƒA'ib $^X $__FILE__\n};
}

if ('ƒƒA' =~ m'ƒa') {
    print qq{not ok - 45 'ƒƒA' =~ m'ƒa' $^X $__FILE__\n};
}
else {
    print qq{ok - 45 'ƒƒA' =~ m'ƒa' $^X $__FILE__\n};
}

if ('ƒƒA' =~ m'ƒa'b) {
    print qq{not ok - 46 'ƒƒA' =~ m'ƒa'b $^X $__FILE__\n};
}
else {
    print qq{ok - 46 'ƒƒA' =~ m'ƒa'b $^X $__FILE__\n};
}

if ('ƒƒA' =~ m'ƒa'i) {
    print qq{not ok - 47 'ƒƒA' =~ m'ƒa'i $^X $__FILE__\n};
}
else {
    print qq{ok - 47 'ƒƒA' =~ m'ƒa'i $^X $__FILE__\n};
}

if ('ƒƒA' =~ m'ƒa'ib) {
    print qq{ok - 48 'ƒƒA' =~ m'ƒa'ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 48 'ƒƒA' =~ m'ƒa'ib $^X $__FILE__\n};
}

if ('ƒƒa' =~ m'ƒA') {
    print qq{not ok - 49 'ƒƒa' =~ m'ƒA' $^X $__FILE__\n};
}
else {
    print qq{ok - 49 'ƒƒa' =~ m'ƒA' $^X $__FILE__\n};
}

if ('ƒƒa' =~ m'ƒA'b) {
    print qq{not ok - 50 'ƒƒa' =~ m'ƒA'b $^X $__FILE__\n};
}
else {
    print qq{ok - 50 'ƒƒa' =~ m'ƒA'b $^X $__FILE__\n};
}

if ('ƒƒa' =~ m'ƒA'i) {
    print qq{not ok - 51 'ƒƒa' =~ m'ƒA'i $^X $__FILE__\n};
}
else {
    print qq{ok - 51 'ƒƒa' =~ m'ƒA'i $^X $__FILE__\n};
}

if ('ƒƒa' =~ m'ƒA'ib) {
    print qq{ok - 52 'ƒƒa' =~ m'ƒA'ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 52 'ƒƒa' =~ m'ƒA'ib $^X $__FILE__\n};
}

if ('ƒƒa' =~ m'ƒa') {
    print qq{not ok - 53 'ƒƒa' =~ m'ƒa' $^X $__FILE__\n};
}
else {
    print qq{ok - 53 'ƒƒa' =~ m'ƒa' $^X $__FILE__\n};
}

if ('ƒƒa' =~ m'ƒa'b) {
    print qq{ok - 54 'ƒƒa' =~ m'ƒa'b $^X $__FILE__\n};
}
else {
    print qq{not ok - 54 'ƒƒa' =~ m'ƒa'b $^X $__FILE__\n};
}

if ('ƒƒa' =~ m'ƒa'i) {
    print qq{not ok - 55 'ƒƒa' =~ m'ƒa'i $^X $__FILE__\n};
}
else {
    print qq{ok - 55 'ƒƒa' =~ m'ƒa'i $^X $__FILE__\n};
}

if ('ƒƒa' =~ m'ƒa'ib) {
    print qq{ok - 56 'ƒƒa' =~ m'ƒa'ib $^X $__FILE__\n};
}
else {
    print qq{not ok - 56 'ƒƒa' =~ m'ƒa'ib $^X $__FILE__\n};
}

__END__

